import request from '@/utils/request'

// 查询咨询信息列表
export function listCOUNSELINGMESSAGE(query) {
  return request({
    url: '/COUNSELINGMESSAGE/list',
    method: 'get',
    params: query
  })
}

// 查询咨询信息所有列表
export function listAllCOUNSELINGMESSAGE(query) {
  return request({
    url: '/COUNSELINGMESSAGE/listAll',
    method: 'get',
    params: query
  })
}

// 查询咨询信息详细
export function getCOUNSELINGMESSAGE(id) {
  return request({
    url: '/COUNSELINGMESSAGE/getInfo/' + id,
    method: 'get'
  })
}

// 新增咨询信息
export function addCOUNSELINGMESSAGE(data) {
  return request({
    url: '/COUNSELINGMESSAGE/add',
    method: 'post',
    data: data
  })
}

// 修改咨询信息
export function updateCOUNSELINGMESSAGE(data) {
  return request({
    url: '/COUNSELINGMESSAGE/edit',
    method: 'post',
    data: data
  })
}

// 删除咨询信息
export function delCOUNSELINGMESSAGE(id) {
  return request({
    url: '/COUNSELINGMESSAGE/remove/' + id,
    method: 'get'
  })
}
// 上传文件
export function upload(data) {
  return request({
    url: '/common/upload/',
    method: 'post',
    data:data
  })
}

// 提交审核   暂存提交  驳回提交   新增新闻都需要调用这个
export function newCommit(data) {
  return request({
    url: '/COUNSELINGMESSAGE/audit/',
    method: 'post',
    data:data
  })
}
